/*
 * Copyright 2024 KylinSoft Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <https://www.gnu.org/licenses/>.
 */

#include "ondeviceengine.h"
#include "ondevicenlpengine.h"
#include "ondevicespeechengine.h"

namespace ai_engine::lm {

std::vector<AiCapability> OndeviceAiEngine::aiCapabilities() const {
    return {AiCapability::Nlp,AiCapability::Speech};
}

std::unique_ptr<nlp::AbstractNlpEngine> OndeviceAiEngine::createNlpEngine() {

    return std::unique_ptr<nlp::AbstractNlpEngine>(new nlp::OndeviceNlpEngine());
}

std::unique_ptr<speech::AbstractSpeechEngine> OndeviceAiEngine::createSpeechEngine() {
    return std::unique_ptr<speech::AbstractSpeechEngine>(new speech::OndeviceSpeechEngine());
}

std::unique_ptr<vision::AbstractVisionEngine> OndeviceAiEngine::createVisionEngine() {
    return std::unique_ptr<vision::AbstractVisionEngine>();
}

AI_LARGE_MODEL_ENGINE_FACTORY(OndeviceAiEngine);

} // namespace ai_engine::lm
